@@ -1,5 +1,3 @@
-from __future__ import annotations
-
 from typing import Any, Optional
 
 from vial.errors import ServerError
@@ -7,12 +5,12 @@ from vial.types import Request
 
 
 class RequestContext:
-    _INSTANCE: Optional[RequestContext] = None
+    _INSTANCE: Optional["RequestContext"] = None
 
     def __init__(self, request: Request) -> None:
         self.request = request
 
-    def __enter__(self) -> RequestContext:
+    def __enter__(self) -> "RequestContext":
         RequestContext._INSTANCE = self
         return self
 
@@ -20,7 +18,7 @@ class RequestContext:
         RequestContext._INSTANCE = None
 
     @classmethod
-    def active(cls) -> RequestContext:
+    def active(cls) -> "RequestContext":
         if not cls._INSTANCE:
             raise ServerError("Not currently within a request")
         return cls._INSTANCE
